var namespacecom_1_1sun_1_1star_1_1text =
[
    [ "fieldmaster", "namespacecom_1_1sun_1_1star_1_1text_1_1fieldmaster.html", "namespacecom_1_1sun_1_1star_1_1text_1_1fieldmaster" ],
    [ "textfield", "namespacecom_1_1sun_1_1star_1_1text_1_1textfield.html", "namespacecom_1_1sun_1_1star_1_1text_1_1textfield" ],
    [ "AuthorDisplayFormat", "namespacecom_1_1sun_1_1star_1_1text_1_1AuthorDisplayFormat.html", [
      [ "FIRST_NAME", "namespacecom_1_1sun_1_1star_1_1text_1_1AuthorDisplayFormat.html#ad44600454c69e9d9baaffc9664eee22a", null ],
      [ "FULL", "namespacecom_1_1sun_1_1star_1_1text_1_1AuthorDisplayFormat.html#aa7394779af9cbf9c78f406e7240fbd5e", null ],
      [ "INITIALS", "namespacecom_1_1sun_1_1star_1_1text_1_1AuthorDisplayFormat.html#a68b0977264bdba3b85642ceac371eb50", null ],
      [ "LAST_NAME", "namespacecom_1_1sun_1_1star_1_1text_1_1AuthorDisplayFormat.html#a2b6d310d457e5642fa8a2af0db41cdef", null ]
    ] ],
    [ "BibliographyDataField", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html", [
      [ "ADDRESS", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a0403bec526648056c66a42644e170fca", null ],
      [ "ANNOTE", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a6d2eee76e12b890a60e57781dce142ed", null ],
      [ "AUTHOR", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a6527648d2d491c859f684ab86eb65033", null ],
      [ "BIBILIOGRAPHIC_TYPE", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a5ee9bcf0d4fbbe7626eecde02faae8b0", null ],
      [ "BOOKTITLE", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a8de42e3ccf0b8a070812f805c43d9dee", null ],
      [ "CHAPTER", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a56e92b064c6babe2714f876ec12d0048", null ],
      [ "CUSTOM1", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#ac03908ee38f25c50ecfc9acf9f5da749", null ],
      [ "CUSTOM2", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a68f3c112f90e73ffdad2c88c24060f37", null ],
      [ "CUSTOM3", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a015159ff33d2b9fd0316be4703c3d0bf", null ],
      [ "CUSTOM4", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a12c9b6d190a60f4e7ddb9db2f6047dd0", null ],
      [ "CUSTOM5", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#afeb72b872dc8acf3c3596cab5d003e19", null ],
      [ "EDITION", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a2ba1321e3472d72618b920a325fe08dc", null ],
      [ "EDITOR", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a0764ec78832e42c8708d4179702a574f", null ],
      [ "HOWPUBLISHED", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#aaaabbc414341d7f121ddc70e65c916f6", null ],
      [ "IDENTIFIER", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#abb81f9a2b5ed677f3e61143b01621260", null ],
      [ "INSTITUTION", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#afdeab4d0230c55b1839dbc1216ab662e", null ],
      [ "ISBN", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a3a393ecbb24fc0fa02c90b25747b2195", null ],
      [ "JOURNAL", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a76c72d9a192bb0601aa1f27013fad3fd", null ],
      [ "LOCAL_URL", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a58702551ec2fee8da92ac80ab0daacfb", null ],
      [ "MONTH", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a9ae9a8899739c114346425a013959238", null ],
      [ "NOTE", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a47f7714142f6a216d2ce5847e3dfc11f", null ],
      [ "NUMBER", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a433879109b2f785c8eff78d226a380c4", null ],
      [ "ORGANIZATIONS", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#ac14be090cf58ae72d6519563126e15fd", null ],
      [ "PAGES", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a29492b3b5a9fd6e79adc2b25468e0b78", null ],
      [ "PUBLISHER", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a115ec456577f16a727f58e3f000fac89", null ],
      [ "REPORT_TYPE", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a4431ce3e3d5cf16f6037f96b411b9f8b", null ],
      [ "SCHOOL", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a0ec865d3533f6e262fa8516cbed8df21", null ],
      [ "SERIES", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a06638e4d2ec17ef38ae9cfc2084530ff", null ],
      [ "TITLE", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a06e9115d300461e2736d25b9849c8c6f", null ],
      [ "URL", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a7f75914945812b9f3dcc0de4fd6650cb", null ],
      [ "VOLUME", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#aa899617b49f3cf3c8287e2dedb58f6b9", null ],
      [ "YEAR", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a64b376cc125810dd498fa6ceee8e2b04", null ]
    ] ],
    [ "BibliographyDataType", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html", [
      [ "ARTICLE", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#ac21b8ad341fecb3e46f397a21b1e126c", null ],
      [ "BOOK", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#ae519d8ae9641b2ce1f1c5658f10aaef0", null ],
      [ "BOOKLET", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#acfaf54d2faafa68e99b2cac7df13ad44", null ],
      [ "CONFERENCE", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a274b09d3007ed7476e2331534b2862e5", null ],
      [ "CUSTOM1", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#ac03908ee38f25c50ecfc9acf9f5da749", null ],
      [ "CUSTOM2", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a68f3c112f90e73ffdad2c88c24060f37", null ],
      [ "CUSTOM3", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a015159ff33d2b9fd0316be4703c3d0bf", null ],
      [ "CUSTOM4", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a12c9b6d190a60f4e7ddb9db2f6047dd0", null ],
      [ "CUSTOM5", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#afeb72b872dc8acf3c3596cab5d003e19", null ],
      [ "EMAIL", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a696ee879900fcbdc1f2d583da3b1db87", null ],
      [ "INBOOK", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a4f5d05208a3150f9ebbe6b6f3ea655df", null ],
      [ "INCOLLECTION", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a67312313be1d895734441331151e06f2", null ],
      [ "INPROCEEDINGS", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#afec7224c7f51e67c232c1b7eb9bfd2d5", null ],
      [ "JOURNAL", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a76c72d9a192bb0601aa1f27013fad3fd", null ],
      [ "MANUAL", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a09541f267e84f73e960b004a9e4b73c3", null ],
      [ "MASTERSTHESIS", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a5b5b11f052bec5fc11cf85589edef455", null ],
      [ "MISC", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#ad686901de107662826945c534537bb35", null ],
      [ "PHDTHESIS", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a3906ee64aca0c6bfbde70e145e5910a6", null ],
      [ "PROCEEDINGS", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#ac0c8dc1bf018c0aecb96e0e3b8ff091c", null ],
      [ "TECHREPORT", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a3f6590c57b47a9fb00b574a9fe6447f6", null ],
      [ "UNPUBLISHED", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#aebe2c1c4afefb75e2014f1282ea685de", null ],
      [ "WWW", "namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a47260728105c0d80db4ac7a24b3e3811", null ]
    ] ],
    [ "ChapterFormat", "namespacecom_1_1sun_1_1star_1_1text_1_1ChapterFormat.html", [
      [ "DIGIT", "namespacecom_1_1sun_1_1star_1_1text_1_1ChapterFormat.html#a69eb0b917afba2a25ae496f9ce9533fe", null ],
      [ "NAME", "namespacecom_1_1sun_1_1star_1_1text_1_1ChapterFormat.html#a6c79dab48c64321032247d8004c472ed", null ],
      [ "NAME_NUMBER", "namespacecom_1_1sun_1_1star_1_1text_1_1ChapterFormat.html#ae62f5d3244ba7e56e004dcd1eca83f0c", null ],
      [ "NO_PREFIX_SUFFIX", "namespacecom_1_1sun_1_1star_1_1text_1_1ChapterFormat.html#aed10e99f8119d20f87798833fe92054c", null ],
      [ "NUMBER", "namespacecom_1_1sun_1_1star_1_1text_1_1ChapterFormat.html#a433879109b2f785c8eff78d226a380c4", null ]
    ] ],
    [ "CharacterCompressionType", "namespacecom_1_1sun_1_1star_1_1text_1_1CharacterCompressionType.html", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1text_1_1CharacterCompressionType.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ],
      [ "PUNCTUATION_AND_KANA", "namespacecom_1_1sun_1_1star_1_1text_1_1CharacterCompressionType.html#a0377d7f10887bebd364ca3ce63fc0833", null ],
      [ "PUNCTUATION_ONLY", "namespacecom_1_1sun_1_1star_1_1text_1_1CharacterCompressionType.html#a349d5fd1091afdcc5ce7b30a3433d809", null ]
    ] ],
    [ "ColumnSeparatorStyle", "namespacecom_1_1sun_1_1star_1_1text_1_1ColumnSeparatorStyle.html", [
      [ "DASHED", "namespacecom_1_1sun_1_1star_1_1text_1_1ColumnSeparatorStyle.html#aeccc1bdf0621ccf3fe5421435c9fcaf9", null ],
      [ "DOTTED", "namespacecom_1_1sun_1_1star_1_1text_1_1ColumnSeparatorStyle.html#a99d5f9e558713447474eaaedde8ff3ea", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1text_1_1ColumnSeparatorStyle.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ],
      [ "SOLID", "namespacecom_1_1sun_1_1star_1_1text_1_1ColumnSeparatorStyle.html#a58fe3c32bba2128d043a6bd83795c997", null ]
    ] ],
    [ "ControlCharacter", "namespacecom_1_1sun_1_1star_1_1text_1_1ControlCharacter.html", [
      [ "APPEND_PARAGRAPH", "namespacecom_1_1sun_1_1star_1_1text_1_1ControlCharacter.html#a8883efe31470c0d49cdd92225b5a9789", null ],
      [ "HARD_HYPHEN", "namespacecom_1_1sun_1_1star_1_1text_1_1ControlCharacter.html#a89bba5c2e969d41ffe6949638d183863", null ],
      [ "HARD_SPACE", "namespacecom_1_1sun_1_1star_1_1text_1_1ControlCharacter.html#ac2e79cd661e77a6669c942eadca2c01d", null ],
      [ "LINE_BREAK", "namespacecom_1_1sun_1_1star_1_1text_1_1ControlCharacter.html#a7c84bbe119ab883c94102a433b13083e", null ],
      [ "PARAGRAPH_BREAK", "namespacecom_1_1sun_1_1star_1_1text_1_1ControlCharacter.html#aa7d8ad3eefce3da2b75f6f962ede7ea4", null ],
      [ "SOFT_HYPHEN", "namespacecom_1_1sun_1_1star_1_1text_1_1ControlCharacter.html#a729506c85f677f0011c022172a6d3566", null ]
    ] ],
    [ "DateDisplayFormat", "namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html", [
      [ "DDMMMMYYYY", "namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html#a0ce2bb5243119e729856bde99473d86e", null ],
      [ "DDMMMYYYY", "namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html#a1ee725c5dd9007819857aeed3d8ce3ef", null ],
      [ "MMDDYY", "namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html#aa42d2d68e1d6883d3c437769bb828dd8", null ],
      [ "MMDDYYYY", "namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html#a49485498c83d8e3d7c5088f6d6faecfb", null ],
      [ "NNDDMMMMYYYY", "namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html#accf5e07d726c7c604555e97cc9c35473", null ],
      [ "NNNNDDMMMMYYYY", "namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html#aa31a9e1ebf94a81dd73ed064eb4bd52e", null ],
      [ "STANDARD_LONG", "namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html#a8b233db6ecd06cdbced3903030ed2736", null ],
      [ "STANDARD_SHORT", "namespacecom_1_1sun_1_1star_1_1text_1_1DateDisplayFormat.html#a03193f22983896fa8f4c640d4f949d8f", null ]
    ] ],
    [ "DocumentStatistic", "namespacecom_1_1sun_1_1star_1_1text_1_1DocumentStatistic.html", [
      [ "CHARS", "namespacecom_1_1sun_1_1star_1_1text_1_1DocumentStatistic.html#a9e43ed7b76cde6a1382a9b9ed5b81cb7", null ],
      [ "PAGES", "namespacecom_1_1sun_1_1star_1_1text_1_1DocumentStatistic.html#a29492b3b5a9fd6e79adc2b25468e0b78", null ],
      [ "PARAS", "namespacecom_1_1sun_1_1star_1_1text_1_1DocumentStatistic.html#a691561f0ca5b6cb6be39798f618a3edd", null ],
      [ "WORDS", "namespacecom_1_1sun_1_1star_1_1text_1_1DocumentStatistic.html#a4d5fc0096b0e2d120b31eaab2d7d85f0", null ]
    ] ],
    [ "FilenameDisplayFormat", "namespacecom_1_1sun_1_1star_1_1text_1_1FilenameDisplayFormat.html", [
      [ "FULL", "namespacecom_1_1sun_1_1star_1_1text_1_1FilenameDisplayFormat.html#aa7394779af9cbf9c78f406e7240fbd5e", null ],
      [ "NAME", "namespacecom_1_1sun_1_1star_1_1text_1_1FilenameDisplayFormat.html#a6c79dab48c64321032247d8004c472ed", null ],
      [ "NAME_AND_EXT", "namespacecom_1_1sun_1_1star_1_1text_1_1FilenameDisplayFormat.html#ac08d5b6992ffb6e6f98d0100bbc44ead", null ],
      [ "PATH", "namespacecom_1_1sun_1_1star_1_1text_1_1FilenameDisplayFormat.html#ab3d7d455b6bfa7acd7f91e6d224be2e6", null ]
    ] ],
    [ "FontEmphasis", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html", [
      [ "ACCENT_ABOVE", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html#a01771198e317f7c48820c86eb9c96d78", null ],
      [ "ACCENT_BELOW", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html#ada5833601874e416b606d96cdbd419bf", null ],
      [ "CIRCLE_ABOVE", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html#a1f0a62ebf8982315d7807f785edaeeed", null ],
      [ "CIRCLE_BELOW", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html#afcc56545972cf01fea0d9e4c7ddeaef7", null ],
      [ "DISK_ABOVE", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html#a0b5f31e1c9cd03d60c14be6c74caa5ba", null ],
      [ "DISK_BELOW", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html#abac20dedfd43301ccb1445c0885aa49e", null ],
      [ "DOT_ABOVE", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html#a30c5bc29f24cae8b92ffa30579f666e1", null ],
      [ "DOT_BELOW", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html#a48f99d49ac32bbf304f26fe5740741e2", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1text_1_1FontEmphasis.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ]
    ] ],
    [ "FontRelief", "namespacecom_1_1sun_1_1star_1_1text_1_1FontRelief.html", [
      [ "EMBOSSED", "namespacecom_1_1sun_1_1star_1_1text_1_1FontRelief.html#a47ab48d4f65ec2bca70278fa6522f2aa", null ],
      [ "ENGRAVED", "namespacecom_1_1sun_1_1star_1_1text_1_1FontRelief.html#a1811d73091776aa72516ff67b7a73bee", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1text_1_1FontRelief.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ]
    ] ],
    [ "FootnoteNumbering", "namespacecom_1_1sun_1_1star_1_1text_1_1FootnoteNumbering.html", [
      [ "PER_CHAPTER", "namespacecom_1_1sun_1_1star_1_1text_1_1FootnoteNumbering.html#a2b000591fe13dc0298aadf1015c05041", null ],
      [ "PER_DOCUMENT", "namespacecom_1_1sun_1_1star_1_1text_1_1FootnoteNumbering.html#a08fe2ef7c0052776e21db1ce3e11e4be", null ],
      [ "PER_PAGE", "namespacecom_1_1sun_1_1star_1_1text_1_1FootnoteNumbering.html#aba2515ad046bb38b9b83af8a19068115", null ]
    ] ],
    [ "HoriOrientation", "namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html", [
      [ "CENTER", "namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html#ab21f0d0eb5fac783bfd82cfc2cf7eb1b", null ],
      [ "FULL", "namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html#aa7394779af9cbf9c78f406e7240fbd5e", null ],
      [ "INSIDE", "namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html#a2303c48e90872653bd1bbc15a5f09757", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html#a105d61332f9450fb1986a38e7243c3aa", null ],
      [ "LEFT_AND_WIDTH", "namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html#a674e724954e14ec80e90a3668b34c5b8", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ],
      [ "OUTSIDE", "namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html#add3c0c0d5fed92ba47be07e6bcf08bc8", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1text_1_1HoriOrientation.html#a0149ac9c0344cfbfd5771ce1a96af612", null ]
    ] ],
    [ "LabelFollow", "namespacecom_1_1sun_1_1star_1_1text_1_1LabelFollow.html", [
      [ "LISTTAB", "namespacecom_1_1sun_1_1star_1_1text_1_1LabelFollow.html#af4c6bb837850a17720339f5a92cda449", null ],
      [ "NEWLINE", "namespacecom_1_1sun_1_1star_1_1text_1_1LabelFollow.html#a0adc9564caa08744a1b66f0403387099", null ],
      [ "NOTHING", "namespacecom_1_1sun_1_1star_1_1text_1_1LabelFollow.html#a69579a365ffeb8cb09d0d981f09690d1", null ],
      [ "SPACE", "namespacecom_1_1sun_1_1star_1_1text_1_1LabelFollow.html#ab1a35780d93ccc746a77699f3cfd4794", null ]
    ] ],
    [ "MailMergeType", "namespacecom_1_1sun_1_1star_1_1text_1_1MailMergeType.html", [
      [ "FILE", "namespacecom_1_1sun_1_1star_1_1text_1_1MailMergeType.html#ae1487dbbc0b85fc2c21d9dcfc6ed12ca", null ],
      [ "MAIL", "namespacecom_1_1sun_1_1star_1_1text_1_1MailMergeType.html#a3540765129481fc218c81c19a885f669", null ],
      [ "PRINTER", "namespacecom_1_1sun_1_1star_1_1text_1_1MailMergeType.html#a9b10517b5dbf6f477ab408f3f0c34626", null ],
      [ "SHELL", "namespacecom_1_1sun_1_1star_1_1text_1_1MailMergeType.html#a34ba3778d34ae4ee10257edf9fa9c3b0", null ]
    ] ],
    [ "ParagraphHyphenationKeepType", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphHyphenationKeepType.html", [
      [ "ALWAYS", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphHyphenationKeepType.html#a84e0aee29a93e3971a1ca1d31de68afc", null ],
      [ "AUTO", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphHyphenationKeepType.html#af8e90a3faa114b49a6da6b8e3b4a5173", null ],
      [ "COLUMN", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphHyphenationKeepType.html#a45d25f885a3cf0981e024674ef90cd4e", null ],
      [ "PAGE", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphHyphenationKeepType.html#a768a031a5841f979ffa8948fc90ff956", null ],
      [ "SPREAD", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphHyphenationKeepType.html#afec795b2f203866c88d4627f24770819", null ]
    ] ],
    [ "ParagraphVertAlign", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphVertAlign.html", [
      [ "AUTOMATIC", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphVertAlign.html#aadc5799f4ecb5a77ff7cb85e9591a94f", null ],
      [ "BASELINE", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphVertAlign.html#aa19735e6662dbf23940ce1f2f2f5d486", null ],
      [ "BOTTOM", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphVertAlign.html#a047e134a70c9674c249189da852b7a2f", null ],
      [ "CENTER", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphVertAlign.html#ab21f0d0eb5fac783bfd82cfc2cf7eb1b", null ],
      [ "TOP", "namespacecom_1_1sun_1_1star_1_1text_1_1ParagraphVertAlign.html#a49aa8a416f8c0c420ee0003a70a10396", null ]
    ] ],
    [ "PlaceholderType", "namespacecom_1_1sun_1_1star_1_1text_1_1PlaceholderType.html", [
      [ "GRAPHIC", "namespacecom_1_1sun_1_1star_1_1text_1_1PlaceholderType.html#a1b33c11d337bb07bd03b5fd7226dc258", null ],
      [ "OBJECT", "namespacecom_1_1sun_1_1star_1_1text_1_1PlaceholderType.html#a6ae37ffc0dd74d3a8c860e3d779b7d85", null ],
      [ "TABLE", "namespacecom_1_1sun_1_1star_1_1text_1_1PlaceholderType.html#ad12387e3953c3674cd33208f640649cb", null ],
      [ "TEXT", "namespacecom_1_1sun_1_1star_1_1text_1_1PlaceholderType.html#aac0bde11b4db7613140eb642e04b80b0", null ],
      [ "TEXTFRAME", "namespacecom_1_1sun_1_1star_1_1text_1_1PlaceholderType.html#a20e268c2f0510c8a47d385893a1c44ed", null ]
    ] ],
    [ "PositionAndSpaceMode", "namespacecom_1_1sun_1_1star_1_1text_1_1PositionAndSpaceMode.html", [
      [ "LABEL_ALIGNMENT", "namespacecom_1_1sun_1_1star_1_1text_1_1PositionAndSpaceMode.html#a8d15e84657f4a24f0bd97f3600cf73a0", null ],
      [ "LABEL_WIDTH_AND_POSITION", "namespacecom_1_1sun_1_1star_1_1text_1_1PositionAndSpaceMode.html#ad51967f2326830e433ef396ba6bd1718", null ]
    ] ],
    [ "PositionLayoutDir", "namespacecom_1_1sun_1_1star_1_1text_1_1PositionLayoutDir.html", [
      [ "PositionInHoriL2R", "namespacecom_1_1sun_1_1star_1_1text_1_1PositionLayoutDir.html#af3bcf796f1bbe8409fb7682770f17578", null ],
      [ "PositionInLayoutDirOfAnchor", "namespacecom_1_1sun_1_1star_1_1text_1_1PositionLayoutDir.html#ab7ef2496c2c73a88c00ff0689521a374", null ]
    ] ],
    [ "ReferenceFieldPart", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html", [
      [ "CATEGORY_AND_NUMBER", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#a958152df3744d0da0fb3d5eefaea5389", null ],
      [ "CHAPTER", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#a56e92b064c6babe2714f876ec12d0048", null ],
      [ "NUMBER", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#a433879109b2f785c8eff78d226a380c4", null ],
      [ "NUMBER_FULL_CONTEXT", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#ab160c4366a9b212970d78eca5ea32d4d", null ],
      [ "NUMBER_NO_CONTEXT", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#a5ee5a751edb8754b107738c94795e1b7", null ],
      [ "ONLY_CAPTION", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#a6389b1bad2c44c995d38f17a0ae99607", null ],
      [ "ONLY_SEQUENCE_NUMBER", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#a8a215eeefb337521dc50f961d7890d6b", null ],
      [ "PAGE", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#a29bb572b50678c1b43fb73f8e0855d65", null ],
      [ "PAGE_DESC", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#a622e6a9adb0668ced1efdb9038859f91", null ],
      [ "TEXT", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#aac0bde11b4db7613140eb642e04b80b0", null ],
      [ "UP_DOWN", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldPart.html#a1d67151f1dcca33f76ee4c604098ca29", null ]
    ] ],
    [ "ReferenceFieldSource", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldSource.html", [
      [ "BOOKMARK", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldSource.html#acc989e0737ff00a1a32fb60e5bd2b7fa", null ],
      [ "ENDNOTE", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldSource.html#a083581a546792925597ed79b062dfa5e", null ],
      [ "FOOTNOTE", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldSource.html#a0eb4c0bc784c581136029f619dfc5842", null ],
      [ "REFERENCE_MARK", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldSource.html#a5faec6d256022847c6da21c372c5b4b0", null ],
      [ "SEQUENCE_FIELD", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldSource.html#a79efadd60aae7094d9208356eca837a0", null ],
      [ "STYLE", "namespacecom_1_1sun_1_1star_1_1text_1_1ReferenceFieldSource.html#aac6be85aad94da27dc1775d47d3a1e73", null ]
    ] ],
    [ "RelOrientation", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html", [
      [ "CHAR", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#a123a6d70d0c61dbd6930523324050984", null ],
      [ "FRAME", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#ae9630c65bb16fee11124f595138300fc", null ],
      [ "FRAME_LEFT", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#ad970affcd9d2a35c4bd6542dd6a0413d", null ],
      [ "FRAME_RIGHT", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#aa549176ce3f91b89844084057f2dc6e7", null ],
      [ "PAGE_FRAME", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#a718ef2b14f8cfec12e269121ec6cc6a7", null ],
      [ "PAGE_LEFT", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#a4ac9915069dc46e91a57f416e57fe89d", null ],
      [ "PAGE_PRINT_AREA", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#a49d84ca4a2ed46aba63df3e627c882f8", null ],
      [ "PAGE_PRINT_AREA_BOTTOM", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#a024db722465e2eda2d14c572bbd1fa31", null ],
      [ "PAGE_PRINT_AREA_TOP", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#aeda55f25cff764ff8a9124bef7a41527", null ],
      [ "PAGE_RIGHT", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#a2c7eb3a74dadbf4ea61c1a780d993d01", null ],
      [ "PRINT_AREA", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#a5a283b41451df90a6564b131fd80ccf0", null ],
      [ "TEXT_LINE", "namespacecom_1_1sun_1_1star_1_1text_1_1RelOrientation.html#aaa530f64a701d8a1920df8df442168fe", null ]
    ] ],
    [ "RubyPosition", "namespacecom_1_1sun_1_1star_1_1text_1_1RubyPosition.html", [
      [ "ABOVE", "namespacecom_1_1sun_1_1star_1_1text_1_1RubyPosition.html#a727f13e95576a8f3266069db6a48442c", null ],
      [ "BELOW", "namespacecom_1_1sun_1_1star_1_1text_1_1RubyPosition.html#ad1d9389a901b294c6611dddd4f64a0a0", null ],
      [ "INTER_CHARACTER", "namespacecom_1_1sun_1_1star_1_1text_1_1RubyPosition.html#aee6cd2effd9bdf50ef1e767e56e333b9", null ]
    ] ],
    [ "ScriptHintType", "namespacecom_1_1sun_1_1star_1_1text_1_1ScriptHintType.html", [
      [ "ASIAN", "namespacecom_1_1sun_1_1star_1_1text_1_1ScriptHintType.html#a2b78c7483b058bfa9b103a435b15711f", null ],
      [ "AUTOMATIC", "namespacecom_1_1sun_1_1star_1_1text_1_1ScriptHintType.html#aadc5799f4ecb5a77ff7cb85e9591a94f", null ],
      [ "COMPLEX", "namespacecom_1_1sun_1_1star_1_1text_1_1ScriptHintType.html#abe746d0cc85ba7eb3d0ce67c2070a12a", null ],
      [ "IGNORE", "namespacecom_1_1sun_1_1star_1_1text_1_1ScriptHintType.html#a6e42770a212bf079cf3a6c3353304b9c", null ],
      [ "LATIN", "namespacecom_1_1sun_1_1star_1_1text_1_1ScriptHintType.html#a22e80ce32528cc42bc50fa2502e7042f", null ]
    ] ],
    [ "SetVariableType", "namespacecom_1_1sun_1_1star_1_1text_1_1SetVariableType.html", [
      [ "FORMULA", "namespacecom_1_1sun_1_1star_1_1text_1_1SetVariableType.html#a5a889988560151a02c679578815f561d", null ],
      [ "SEQUENCE", "namespacecom_1_1sun_1_1star_1_1text_1_1SetVariableType.html#a0c45cf396b2d341e70d5dd7f558e02cf", null ],
      [ "STRING", "namespacecom_1_1sun_1_1star_1_1text_1_1SetVariableType.html#a21b37d6e782df63ea69b9e32b966f26c", null ],
      [ "VAR", "namespacecom_1_1sun_1_1star_1_1text_1_1SetVariableType.html#a44e92be74282881b9efe332a45feb2bd", null ]
    ] ],
    [ "SizeType", "namespacecom_1_1sun_1_1star_1_1text_1_1SizeType.html", [
      [ "FIX", "namespacecom_1_1sun_1_1star_1_1text_1_1SizeType.html#a983c76a121daf0014424cb34ba29389f", null ],
      [ "MIN", "namespacecom_1_1sun_1_1star_1_1text_1_1SizeType.html#a611d5100dbd668af8673302a2fae0899", null ],
      [ "VARIABLE", "namespacecom_1_1sun_1_1star_1_1text_1_1SizeType.html#aa6931ac31b6238a1f5e45bccf3dce8fd", null ]
    ] ],
    [ "TemplateDisplayFormat", "namespacecom_1_1sun_1_1star_1_1text_1_1TemplateDisplayFormat.html", [
      [ "AREA", "namespacecom_1_1sun_1_1star_1_1text_1_1TemplateDisplayFormat.html#a72d908e4879ea9a56ce370f776a5f2cf", null ],
      [ "FULL", "namespacecom_1_1sun_1_1star_1_1text_1_1TemplateDisplayFormat.html#aa7394779af9cbf9c78f406e7240fbd5e", null ],
      [ "NAME", "namespacecom_1_1sun_1_1star_1_1text_1_1TemplateDisplayFormat.html#a6c79dab48c64321032247d8004c472ed", null ],
      [ "NAME_AND_EXT", "namespacecom_1_1sun_1_1star_1_1text_1_1TemplateDisplayFormat.html#ac08d5b6992ffb6e6f98d0100bbc44ead", null ],
      [ "PATH", "namespacecom_1_1sun_1_1star_1_1text_1_1TemplateDisplayFormat.html#ab3d7d455b6bfa7acd7f91e6d224be2e6", null ],
      [ "TITLE", "namespacecom_1_1sun_1_1star_1_1text_1_1TemplateDisplayFormat.html#a06e9115d300461e2736d25b9849c8c6f", null ]
    ] ],
    [ "TextGridMode", "namespacecom_1_1sun_1_1star_1_1text_1_1TextGridMode.html", [
      [ "LINES", "namespacecom_1_1sun_1_1star_1_1text_1_1TextGridMode.html#a61746476cb6b62d64681153710ed64f6", null ],
      [ "LINES_AND_CHARS", "namespacecom_1_1sun_1_1star_1_1text_1_1TextGridMode.html#a3cad2b6138929d8b57311e619c609c10", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1text_1_1TextGridMode.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ]
    ] ],
    [ "TextMarkupType", "namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html", [
      [ "PROOFREADING", "namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html#ac76ea58363cececba5d534b9089615fa", null ],
      [ "SENTENCE", "namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html#a633ba64c2e50548dc8c5b697669a6ab2", null ],
      [ "SMARTTAG", "namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html#a01734b6cf070cb134669762306ff2903", null ],
      [ "SPELLCHECK", "namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html#a55fcfa291181cfa4ab7344fad591188e", null ],
      [ "TRACK_CHANGE_DELETION", "namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html#a25ffcaec3ee2c156c33d097ea8275693", null ],
      [ "TRACK_CHANGE_FORMATCHANGE", "namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html#a6daf839cb090b9875456431152ddf5c9", null ],
      [ "TRACK_CHANGE_INSERTION", "namespacecom_1_1sun_1_1star_1_1text_1_1TextMarkupType.html#a7844b91d814622cf922ae0536350c6db", null ]
    ] ],
    [ "TimeDisplayFormat", "namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html", [
      [ "HHMM", "namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html#ab94e7648c361fc24dacf78bf8a2bc1d4", null ],
      [ "HHMMAMPM", "namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html#a23a1a0b77bd9919192d4b4966a7e9288", null ],
      [ "HHMMSS", "namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html#ac1fee42c0839d45366cd17e21492f252", null ],
      [ "HHMMSS00", "namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html#a7786432a2b63213220cf4a3d3e91bd74", null ],
      [ "HHMMSS00AMPM", "namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html#a71ab394a7190f34249ce787e78242c28", null ],
      [ "HHMMSSAMPM", "namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html#aec30e73c4b36f24caa242ec82c7fbb13", null ],
      [ "STANDARD", "namespacecom_1_1sun_1_1star_1_1text_1_1TimeDisplayFormat.html#af06c192a014fdda92c6dc3d46d8ab134", null ]
    ] ],
    [ "UserDataPart", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html", [
      [ "CITY", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a196ff56db5e6f59ae7d577e85a9868e4", null ],
      [ "COMPANY", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#aa4aca1885418f476977f3ec026be94ca", null ],
      [ "COUNTRY", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#ad3942d88537dbbd29255ed3a7b19c460", null ],
      [ "EMAIL", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a696ee879900fcbdc1f2d583da3b1db87", null ],
      [ "FAX", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a5953111739947f7eeb32fa8d2e84b39b", null ],
      [ "FIRSTNAME", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a6ae9b6f3231195a61cc9b9bd04fad952", null ],
      [ "NAME", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a6c79dab48c64321032247d8004c472ed", null ],
      [ "PHONE_COMPANY", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a7201843ba646bf02603ffbaff3f215e6", null ],
      [ "PHONE_PRIVATE", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a91c057a4ac954ee86661e5b2d735c561", null ],
      [ "POSITION", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a8cc5aca7f836cf558d08c8db73a3a350", null ],
      [ "SHORTCUT", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a19f68527de032d5b00a03f9ee426dd05", null ],
      [ "STATE", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#adb5141a1270f5f507b5e974f10d41674", null ],
      [ "STREET", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a89bdfd33974f733f7fa2d1fe4a5fe9f3", null ],
      [ "TITLE", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#a06e9115d300461e2736d25b9849c8c6f", null ],
      [ "ZIP", "namespacecom_1_1sun_1_1star_1_1text_1_1UserDataPart.html#af6ba8211f40bc9557ba72a8be24199a4", null ]
    ] ],
    [ "UserFieldFormat", "namespacecom_1_1sun_1_1star_1_1text_1_1UserFieldFormat.html", [
      [ "NUM", "namespacecom_1_1sun_1_1star_1_1text_1_1UserFieldFormat.html#a49bfa55991a6e3e562df86eb4e101dba", null ],
      [ "SYSTEM", "namespacecom_1_1sun_1_1star_1_1text_1_1UserFieldFormat.html#a8cd5849bda67fccbb2cf903fd64ac1d1", null ],
      [ "TEXT", "namespacecom_1_1sun_1_1star_1_1text_1_1UserFieldFormat.html#aac0bde11b4db7613140eb642e04b80b0", null ]
    ] ],
    [ "VertOrientation", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html", [
      [ "BOTTOM", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#a047e134a70c9674c249189da852b7a2f", null ],
      [ "CENTER", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#ab21f0d0eb5fac783bfd82cfc2cf7eb1b", null ],
      [ "CHAR_BOTTOM", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#a32778d42dcf289d6a746776ec924a364", null ],
      [ "CHAR_CENTER", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#a01283ba1690ca839635b1e3ed98b9a55", null ],
      [ "CHAR_TOP", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#ab9cde0d13977cc2184909bea4bd5bc8f", null ],
      [ "LINE_BOTTOM", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#a3bdb7735a9f71e5fde2701a4e5477d84", null ],
      [ "LINE_CENTER", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#a4aa8626baa8ebb17db4bf33e3b5baf38", null ],
      [ "LINE_TOP", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#a7c157113f6f5eccb2ac3101bd1157a09", null ],
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#a87d5fdeecd058bf6c4bf4fddb6724cd8", null ],
      [ "TOP", "namespacecom_1_1sun_1_1star_1_1text_1_1VertOrientation.html#a49aa8a416f8c0c420ee0003a70a10396", null ]
    ] ],
    [ "WrapInfluenceOnPosition", "namespacecom_1_1sun_1_1star_1_1text_1_1WrapInfluenceOnPosition.html", [
      [ "ITERATIVE", "namespacecom_1_1sun_1_1star_1_1text_1_1WrapInfluenceOnPosition.html#aaebafd2a45700f3b49ea87bdbbedd480", null ],
      [ "ONCE_CONCURRENT", "namespacecom_1_1sun_1_1star_1_1text_1_1WrapInfluenceOnPosition.html#a29fb6286548c1f3de1a55d3385852c68", null ],
      [ "ONCE_SUCCESSIVE", "namespacecom_1_1sun_1_1star_1_1text_1_1WrapInfluenceOnPosition.html#a7aa969b6068d32564adfbaa12e568797", null ]
    ] ],
    [ "WritingMode2", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html", [
      [ "BT_LR", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#ab0da9206ed031dbbb3fbcbddfac73d63", null ],
      [ "CONTEXT", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#ad390fa3a12e10922c17e519602f362c7", null ],
      [ "LR_TB", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#a6f0c400272b571c7bdcfb011cd35890f", null ],
      [ "PAGE", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#a29bb572b50678c1b43fb73f8e0855d65", null ],
      [ "RL_TB", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#a6d0d3b5ef8389be98c385f48e0ad44a5", null ],
      [ "STACKED", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#ad2ffd89204a891700376334e16c4bc19", null ],
      [ "TB_LR", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#a644a62cc624f696adbca70ae86a6b943", null ],
      [ "TB_RL", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#a9c68fece2094cf304a00f4d5010955af", null ],
      [ "TB_RL90", "namespacecom_1_1sun_1_1star_1_1text_1_1WritingMode2.html#a189c2e38deaf5a632ae65cf1455b5fe2", null ]
    ] ],
    [ "AutoTextContainer", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextContainer.html", null ],
    [ "AutoTextEntry", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextEntry.html", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextEntry" ],
    [ "AutoTextGroup", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextGroup.html", "servicecom_1_1sun_1_1star_1_1text_1_1AutoTextGroup" ],
    [ "BaseFrame", "servicecom_1_1sun_1_1star_1_1text_1_1BaseFrame.html", "servicecom_1_1sun_1_1star_1_1text_1_1BaseFrame" ],
    [ "BaseFrameProperties", "servicecom_1_1sun_1_1star_1_1text_1_1BaseFrameProperties.html", "servicecom_1_1sun_1_1star_1_1text_1_1BaseFrameProperties" ],
    [ "BaseIndex", "servicecom_1_1sun_1_1star_1_1text_1_1BaseIndex.html", "servicecom_1_1sun_1_1star_1_1text_1_1BaseIndex" ],
    [ "BaseIndexMark", "servicecom_1_1sun_1_1star_1_1text_1_1BaseIndexMark.html", "servicecom_1_1sun_1_1star_1_1text_1_1BaseIndexMark" ],
    [ "Bibliography", "servicecom_1_1sun_1_1star_1_1text_1_1Bibliography.html", "servicecom_1_1sun_1_1star_1_1text_1_1Bibliography" ],
    [ "Bookmark", "servicecom_1_1sun_1_1star_1_1text_1_1Bookmark.html", "servicecom_1_1sun_1_1star_1_1text_1_1Bookmark" ],
    [ "Bookmarks", "servicecom_1_1sun_1_1star_1_1text_1_1Bookmarks.html", "servicecom_1_1sun_1_1star_1_1text_1_1Bookmarks" ],
    [ "Cell", "servicecom_1_1sun_1_1star_1_1text_1_1Cell.html", "servicecom_1_1sun_1_1star_1_1text_1_1Cell" ],
    [ "CellProperties", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties.html", "servicecom_1_1sun_1_1star_1_1text_1_1CellProperties" ],
    [ "CellRange", "servicecom_1_1sun_1_1star_1_1text_1_1CellRange.html", "servicecom_1_1sun_1_1star_1_1text_1_1CellRange" ],
    [ "ChainedTextFrame", "servicecom_1_1sun_1_1star_1_1text_1_1ChainedTextFrame.html", "servicecom_1_1sun_1_1star_1_1text_1_1ChainedTextFrame" ],
    [ "ChapterNumberingRule", "servicecom_1_1sun_1_1star_1_1text_1_1ChapterNumberingRule.html", "servicecom_1_1sun_1_1star_1_1text_1_1ChapterNumberingRule" ],
    [ "ContentControl", "servicecom_1_1sun_1_1star_1_1text_1_1ContentControl.html", "servicecom_1_1sun_1_1star_1_1text_1_1ContentControl" ],
    [ "ContentIndex", "servicecom_1_1sun_1_1star_1_1text_1_1ContentIndex.html", "servicecom_1_1sun_1_1star_1_1text_1_1ContentIndex" ],
    [ "ContentIndexMark", "servicecom_1_1sun_1_1star_1_1text_1_1ContentIndexMark.html", "servicecom_1_1sun_1_1star_1_1text_1_1ContentIndexMark" ],
    [ "DefaultNumberingProvider", "servicecom_1_1sun_1_1star_1_1text_1_1DefaultNumberingProvider.html", null ],
    [ "Defaults", "servicecom_1_1sun_1_1star_1_1text_1_1Defaults.html", "servicecom_1_1sun_1_1star_1_1text_1_1Defaults" ],
    [ "DependentTextField", "servicecom_1_1sun_1_1star_1_1text_1_1DependentTextField.html", "servicecom_1_1sun_1_1star_1_1text_1_1DependentTextField" ],
    [ "DialogFactoryService", "servicecom_1_1sun_1_1star_1_1text_1_1DialogFactoryService.html", null ],
    [ "DocumentIndex", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndex.html", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndex" ],
    [ "DocumentIndexes", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexes.html", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexes" ],
    [ "DocumentIndexLevelFormat", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexLevelFormat.html", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexLevelFormat" ],
    [ "DocumentIndexMark", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexMark.html", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexMark" ],
    [ "DocumentIndexMarkAsian", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexMarkAsian.html", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexMarkAsian" ],
    [ "DocumentIndexParagraphStyles", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexParagraphStyles.html", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentIndexParagraphStyles" ],
    [ "DocumentSettings", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings.html", "servicecom_1_1sun_1_1star_1_1text_1_1DocumentSettings" ],
    [ "Endnote", "servicecom_1_1sun_1_1star_1_1text_1_1Endnote.html", "servicecom_1_1sun_1_1star_1_1text_1_1Endnote" ],
    [ "EndnoteSettings", "servicecom_1_1sun_1_1star_1_1text_1_1EndnoteSettings.html", "servicecom_1_1sun_1_1star_1_1text_1_1EndnoteSettings" ],
    [ "Footnote", "servicecom_1_1sun_1_1star_1_1text_1_1Footnote.html", "servicecom_1_1sun_1_1star_1_1text_1_1Footnote" ],
    [ "Footnotes", "servicecom_1_1sun_1_1star_1_1text_1_1Footnotes.html", "servicecom_1_1sun_1_1star_1_1text_1_1Footnotes" ],
    [ "FootnoteSettings", "servicecom_1_1sun_1_1star_1_1text_1_1FootnoteSettings.html", "servicecom_1_1sun_1_1star_1_1text_1_1FootnoteSettings" ],
    [ "GenericTextDocument", "servicecom_1_1sun_1_1star_1_1text_1_1GenericTextDocument.html", "servicecom_1_1sun_1_1star_1_1text_1_1GenericTextDocument" ],
    [ "GlobalDocument", "servicecom_1_1sun_1_1star_1_1text_1_1GlobalDocument.html", "servicecom_1_1sun_1_1star_1_1text_1_1GlobalDocument" ],
    [ "GlobalSettings", "servicecom_1_1sun_1_1star_1_1text_1_1GlobalSettings.html", "servicecom_1_1sun_1_1star_1_1text_1_1GlobalSettings" ],
    [ "GraphicCrop", "structcom_1_1sun_1_1star_1_1text_1_1GraphicCrop.html", "structcom_1_1sun_1_1star_1_1text_1_1GraphicCrop" ],
    [ "HoriOrientationFormat", "structcom_1_1sun_1_1star_1_1text_1_1HoriOrientationFormat.html", "structcom_1_1sun_1_1star_1_1text_1_1HoriOrientationFormat" ],
    [ "IllustrationsIndex", "servicecom_1_1sun_1_1star_1_1text_1_1IllustrationsIndex.html", "servicecom_1_1sun_1_1star_1_1text_1_1IllustrationsIndex" ],
    [ "InContentMetadata", "servicecom_1_1sun_1_1star_1_1text_1_1InContentMetadata.html", "servicecom_1_1sun_1_1star_1_1text_1_1InContentMetadata" ],
    [ "InvalidTextContentException", "exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException.html", "exceptioncom_1_1sun_1_1star_1_1text_1_1InvalidTextContentException" ],
    [ "LineBreak", "servicecom_1_1sun_1_1star_1_1text_1_1LineBreak.html", "servicecom_1_1sun_1_1star_1_1text_1_1LineBreak" ],
    [ "LineNumberingProperties", "servicecom_1_1sun_1_1star_1_1text_1_1LineNumberingProperties.html", "servicecom_1_1sun_1_1star_1_1text_1_1LineNumberingProperties" ],
    [ "MailMerge", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge.html", "servicecom_1_1sun_1_1star_1_1text_1_1MailMerge" ],
    [ "MailMergeEvent", "structcom_1_1sun_1_1star_1_1text_1_1MailMergeEvent.html", "structcom_1_1sun_1_1star_1_1text_1_1MailMergeEvent" ],
    [ "ModuleDispatcher", "servicecom_1_1sun_1_1star_1_1text_1_1ModuleDispatcher.html", null ],
    [ "NumberingLevel", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingLevel.html", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingLevel" ],
    [ "NumberingRules", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules.html", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingRules" ],
    [ "NumberingStyle", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingStyle.html", "servicecom_1_1sun_1_1star_1_1text_1_1NumberingStyle" ],
    [ "ObjectIndex", "servicecom_1_1sun_1_1star_1_1text_1_1ObjectIndex.html", "servicecom_1_1sun_1_1star_1_1text_1_1ObjectIndex" ],
    [ "PageFootnoteInfo", "servicecom_1_1sun_1_1star_1_1text_1_1PageFootnoteInfo.html", "servicecom_1_1sun_1_1star_1_1text_1_1PageFootnoteInfo" ],
    [ "PagePrintSettings", "servicecom_1_1sun_1_1star_1_1text_1_1PagePrintSettings.html", "servicecom_1_1sun_1_1star_1_1text_1_1PagePrintSettings" ],
    [ "Paragraph", "servicecom_1_1sun_1_1star_1_1text_1_1Paragraph.html", "servicecom_1_1sun_1_1star_1_1text_1_1Paragraph" ],
    [ "ParagraphEnumeration", "servicecom_1_1sun_1_1star_1_1text_1_1ParagraphEnumeration.html", "servicecom_1_1sun_1_1star_1_1text_1_1ParagraphEnumeration" ],
    [ "PrintSettings", "servicecom_1_1sun_1_1star_1_1text_1_1PrintSettings.html", "servicecom_1_1sun_1_1star_1_1text_1_1PrintSettings" ],
    [ "RedlinePortion", "servicecom_1_1sun_1_1star_1_1text_1_1RedlinePortion.html", "servicecom_1_1sun_1_1star_1_1text_1_1RedlinePortion" ],
    [ "ReferenceMark", "servicecom_1_1sun_1_1star_1_1text_1_1ReferenceMark.html", "servicecom_1_1sun_1_1star_1_1text_1_1ReferenceMark" ],
    [ "ReferenceMarks", "servicecom_1_1sun_1_1star_1_1text_1_1ReferenceMarks.html", "servicecom_1_1sun_1_1star_1_1text_1_1ReferenceMarks" ],
    [ "SectionFileLink", "structcom_1_1sun_1_1star_1_1text_1_1SectionFileLink.html", "structcom_1_1sun_1_1star_1_1text_1_1SectionFileLink" ],
    [ "Shape", "servicecom_1_1sun_1_1star_1_1text_1_1Shape.html", "servicecom_1_1sun_1_1star_1_1text_1_1Shape" ],
    [ "TableColumns", "servicecom_1_1sun_1_1star_1_1text_1_1TableColumns.html", "servicecom_1_1sun_1_1star_1_1text_1_1TableColumns" ],
    [ "TableColumnSeparator", "structcom_1_1sun_1_1star_1_1text_1_1TableColumnSeparator.html", "structcom_1_1sun_1_1star_1_1text_1_1TableColumnSeparator" ],
    [ "TableIndex", "servicecom_1_1sun_1_1star_1_1text_1_1TableIndex.html", "servicecom_1_1sun_1_1star_1_1text_1_1TableIndex" ],
    [ "TableRows", "servicecom_1_1sun_1_1star_1_1text_1_1TableRows.html", "servicecom_1_1sun_1_1star_1_1text_1_1TableRows" ],
    [ "Text", "servicecom_1_1sun_1_1star_1_1text_1_1Text.html", "servicecom_1_1sun_1_1star_1_1text_1_1Text" ],
    [ "TextColumn", "structcom_1_1sun_1_1star_1_1text_1_1TextColumn.html", "structcom_1_1sun_1_1star_1_1text_1_1TextColumn" ],
    [ "TextColumns", "servicecom_1_1sun_1_1star_1_1text_1_1TextColumns.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextColumns" ],
    [ "TextContent", "servicecom_1_1sun_1_1star_1_1text_1_1TextContent.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextContent" ],
    [ "TextContentCollection", "servicecom_1_1sun_1_1star_1_1text_1_1TextContentCollection.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextContentCollection" ],
    [ "TextCursor", "servicecom_1_1sun_1_1star_1_1text_1_1TextCursor.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextCursor" ],
    [ "TextDocument", "servicecom_1_1sun_1_1star_1_1text_1_1TextDocument.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextDocument" ],
    [ "TextDocumentView", "servicecom_1_1sun_1_1star_1_1text_1_1TextDocumentView.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextDocumentView" ],
    [ "TextEmbeddedObject", "servicecom_1_1sun_1_1star_1_1text_1_1TextEmbeddedObject.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextEmbeddedObject" ],
    [ "TextEmbeddedObjects", "servicecom_1_1sun_1_1star_1_1text_1_1TextEmbeddedObjects.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextEmbeddedObjects" ],
    [ "TextField", "servicecom_1_1sun_1_1star_1_1text_1_1TextField.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextField" ],
    [ "TextFieldEnumeration", "servicecom_1_1sun_1_1star_1_1text_1_1TextFieldEnumeration.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextFieldEnumeration" ],
    [ "TextFieldMaster", "servicecom_1_1sun_1_1star_1_1text_1_1TextFieldMaster.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextFieldMaster" ],
    [ "TextFieldMasters", "servicecom_1_1sun_1_1star_1_1text_1_1TextFieldMasters.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextFieldMasters" ],
    [ "TextFields", "servicecom_1_1sun_1_1star_1_1text_1_1TextFields.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextFields" ],
    [ "TextFrame", "servicecom_1_1sun_1_1star_1_1text_1_1TextFrame.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextFrame" ],
    [ "TextFrames", "servicecom_1_1sun_1_1star_1_1text_1_1TextFrames.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextFrames" ],
    [ "TextGraphicObject", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObject" ],
    [ "TextGraphicObjects", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObjects.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextGraphicObjects" ],
    [ "TextLayoutCursor", "servicecom_1_1sun_1_1star_1_1text_1_1TextLayoutCursor.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextLayoutCursor" ],
    [ "TextMarkupDescriptor", "structcom_1_1sun_1_1star_1_1text_1_1TextMarkupDescriptor.html", "structcom_1_1sun_1_1star_1_1text_1_1TextMarkupDescriptor" ],
    [ "TextPageStyle", "servicecom_1_1sun_1_1star_1_1text_1_1TextPageStyle.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextPageStyle" ],
    [ "TextPortion", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortion" ],
    [ "TextPortionEnumeration", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortionEnumeration.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextPortionEnumeration" ],
    [ "TextPosition", "structcom_1_1sun_1_1star_1_1text_1_1TextPosition.html", "structcom_1_1sun_1_1star_1_1text_1_1TextPosition" ],
    [ "TextRange", "servicecom_1_1sun_1_1star_1_1text_1_1TextRange.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextRange" ],
    [ "TextRangeContentProperties", "servicecom_1_1sun_1_1star_1_1text_1_1TextRangeContentProperties.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextRangeContentProperties" ],
    [ "TextRanges", "servicecom_1_1sun_1_1star_1_1text_1_1TextRanges.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextRanges" ],
    [ "TextRangeSelection", "structcom_1_1sun_1_1star_1_1text_1_1TextRangeSelection.html", "structcom_1_1sun_1_1star_1_1text_1_1TextRangeSelection" ],
    [ "TextSection", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextSection" ],
    [ "TextSections", "servicecom_1_1sun_1_1star_1_1text_1_1TextSections.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextSections" ],
    [ "TextSortable", "servicecom_1_1sun_1_1star_1_1text_1_1TextSortable.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextSortable" ],
    [ "TextSortDescriptor", "servicecom_1_1sun_1_1star_1_1text_1_1TextSortDescriptor.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextSortDescriptor" ],
    [ "TextSortDescriptor2", "servicecom_1_1sun_1_1star_1_1text_1_1TextSortDescriptor2.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextSortDescriptor2" ],
    [ "TextTable", "servicecom_1_1sun_1_1star_1_1text_1_1TextTable.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextTable" ],
    [ "TextTableCursor", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableCursor.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableCursor" ],
    [ "TextTableRow", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextTableRow" ],
    [ "TextTables", "servicecom_1_1sun_1_1star_1_1text_1_1TextTables.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextTables" ],
    [ "TextViewCursor", "servicecom_1_1sun_1_1star_1_1text_1_1TextViewCursor.html", "servicecom_1_1sun_1_1star_1_1text_1_1TextViewCursor" ],
    [ "UserDefinedIndex", "servicecom_1_1sun_1_1star_1_1text_1_1UserDefinedIndex.html", "servicecom_1_1sun_1_1star_1_1text_1_1UserDefinedIndex" ],
    [ "UserIndex", "servicecom_1_1sun_1_1star_1_1text_1_1UserIndex.html", "servicecom_1_1sun_1_1star_1_1text_1_1UserIndex" ],
    [ "UserIndexMark", "servicecom_1_1sun_1_1star_1_1text_1_1UserIndexMark.html", "servicecom_1_1sun_1_1star_1_1text_1_1UserIndexMark" ],
    [ "VertOrientationFormat", "structcom_1_1sun_1_1star_1_1text_1_1VertOrientationFormat.html", "structcom_1_1sun_1_1star_1_1text_1_1VertOrientationFormat" ],
    [ "ViewSettings", "servicecom_1_1sun_1_1star_1_1text_1_1ViewSettings.html", "servicecom_1_1sun_1_1star_1_1text_1_1ViewSettings" ],
    [ "WebDocument", "servicecom_1_1sun_1_1star_1_1text_1_1WebDocument.html", "servicecom_1_1sun_1_1star_1_1text_1_1WebDocument" ],
    [ "XAutoTextContainer", "interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextContainer.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextContainer" ],
    [ "XAutoTextContainer2", "interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextContainer2.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextContainer2" ],
    [ "XAutoTextEntry", "interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextEntry.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextEntry" ],
    [ "XAutoTextGroup", "interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextGroup.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XAutoTextGroup" ],
    [ "XBookmarkInsertTool", "interfacecom_1_1sun_1_1star_1_1text_1_1XBookmarkInsertTool.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XBookmarkInsertTool" ],
    [ "XBookmarksSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XBookmarksSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XBookmarksSupplier" ],
    [ "XChapterNumberingSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XChapterNumberingSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XChapterNumberingSupplier" ],
    [ "XContentControlsSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XContentControlsSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XContentControlsSupplier" ],
    [ "XDefaultNumberingProvider", "interfacecom_1_1sun_1_1star_1_1text_1_1XDefaultNumberingProvider.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XDefaultNumberingProvider" ],
    [ "XDependentTextField", "interfacecom_1_1sun_1_1star_1_1text_1_1XDependentTextField.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XDependentTextField" ],
    [ "XDocumentIndex", "interfacecom_1_1sun_1_1star_1_1text_1_1XDocumentIndex.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XDocumentIndex" ],
    [ "XDocumentIndexesSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XDocumentIndexesSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XDocumentIndexesSupplier" ],
    [ "XDocumentIndexMark", "interfacecom_1_1sun_1_1star_1_1text_1_1XDocumentIndexMark.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XDocumentIndexMark" ],
    [ "XEndnotesSettingsSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XEndnotesSettingsSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XEndnotesSettingsSupplier" ],
    [ "XEndnotesSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XEndnotesSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XEndnotesSupplier" ],
    [ "XFlatParagraph", "interfacecom_1_1sun_1_1star_1_1text_1_1XFlatParagraph.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XFlatParagraph" ],
    [ "XFlatParagraphIterator", "interfacecom_1_1sun_1_1star_1_1text_1_1XFlatParagraphIterator.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XFlatParagraphIterator" ],
    [ "XFlatParagraphIteratorProvider", "interfacecom_1_1sun_1_1star_1_1text_1_1XFlatParagraphIteratorProvider.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XFlatParagraphIteratorProvider" ],
    [ "XFootnote", "interfacecom_1_1sun_1_1star_1_1text_1_1XFootnote.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XFootnote" ],
    [ "XFootnotesSettingsSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XFootnotesSettingsSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XFootnotesSettingsSupplier" ],
    [ "XFootnotesSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XFootnotesSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XFootnotesSupplier" ],
    [ "XFormField", "interfacecom_1_1sun_1_1star_1_1text_1_1XFormField.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XFormField" ],
    [ "XLineNumberingProperties", "interfacecom_1_1sun_1_1star_1_1text_1_1XLineNumberingProperties.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XLineNumberingProperties" ],
    [ "XMailMergeBroadcaster", "interfacecom_1_1sun_1_1star_1_1text_1_1XMailMergeBroadcaster.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XMailMergeBroadcaster" ],
    [ "XMailMergeListener", "interfacecom_1_1sun_1_1star_1_1text_1_1XMailMergeListener.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XMailMergeListener" ],
    [ "XMarkingAccess", "interfacecom_1_1sun_1_1star_1_1text_1_1XMarkingAccess.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XMarkingAccess" ],
    [ "XMultiTextMarkup", "interfacecom_1_1sun_1_1star_1_1text_1_1XMultiTextMarkup.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XMultiTextMarkup" ],
    [ "XNumberingFormatter", "interfacecom_1_1sun_1_1star_1_1text_1_1XNumberingFormatter.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XNumberingFormatter" ],
    [ "XNumberingRulesSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XNumberingRulesSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XNumberingRulesSupplier" ],
    [ "XNumberingTypeInfo", "interfacecom_1_1sun_1_1star_1_1text_1_1XNumberingTypeInfo.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XNumberingTypeInfo" ],
    [ "XPageCursor", "interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor" ],
    [ "XPagePrintable", "interfacecom_1_1sun_1_1star_1_1text_1_1XPagePrintable.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XPagePrintable" ],
    [ "XParagraphAppend", "interfacecom_1_1sun_1_1star_1_1text_1_1XParagraphAppend.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XParagraphAppend" ],
    [ "XParagraphCursor", "interfacecom_1_1sun_1_1star_1_1text_1_1XParagraphCursor.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XParagraphCursor" ],
    [ "XPasteBroadcaster", "interfacecom_1_1sun_1_1star_1_1text_1_1XPasteBroadcaster.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XPasteBroadcaster" ],
    [ "XPasteListener", "interfacecom_1_1sun_1_1star_1_1text_1_1XPasteListener.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XPasteListener" ],
    [ "XRedline", "interfacecom_1_1sun_1_1star_1_1text_1_1XRedline.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XRedline" ],
    [ "XReferenceMarksSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XReferenceMarksSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XReferenceMarksSupplier" ],
    [ "XRelativeTextContentInsert", "interfacecom_1_1sun_1_1star_1_1text_1_1XRelativeTextContentInsert.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XRelativeTextContentInsert" ],
    [ "XRelativeTextContentRemove", "interfacecom_1_1sun_1_1star_1_1text_1_1XRelativeTextContentRemove.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XRelativeTextContentRemove" ],
    [ "XRubySelection", "interfacecom_1_1sun_1_1star_1_1text_1_1XRubySelection.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XRubySelection" ],
    [ "XSentenceCursor", "interfacecom_1_1sun_1_1star_1_1text_1_1XSentenceCursor.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XSentenceCursor" ],
    [ "XSimpleText", "interfacecom_1_1sun_1_1star_1_1text_1_1XSimpleText.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XSimpleText" ],
    [ "XText", "interfacecom_1_1sun_1_1star_1_1text_1_1XText.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XText" ],
    [ "XTextAppend", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextAppend.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextAppend" ],
    [ "XTextAppendAndConvert", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextAppendAndConvert.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextAppendAndConvert" ],
    [ "XTextColumns", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextColumns.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextColumns" ],
    [ "XTextContent", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextContent.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextContent" ],
    [ "XTextContentAppend", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextContentAppend.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextContentAppend" ],
    [ "XTextConvert", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextConvert.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextConvert" ],
    [ "XTextCopy", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextCopy.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextCopy" ],
    [ "XTextCursor", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextCursor.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextCursor" ],
    [ "XTextDocument", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextDocument.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextDocument" ],
    [ "XTextEmbeddedObjectsSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextEmbeddedObjectsSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextEmbeddedObjectsSupplier" ],
    [ "XTextField", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextField.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextField" ],
    [ "XTextFieldsSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextFieldsSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextFieldsSupplier" ],
    [ "XTextFrame", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextFrame.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextFrame" ],
    [ "XTextFramesSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextFramesSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextFramesSupplier" ],
    [ "XTextGraphicObjectsSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextGraphicObjectsSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextGraphicObjectsSupplier" ],
    [ "XTextMarkup", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextMarkup.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextMarkup" ],
    [ "XTextPortionAppend", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextPortionAppend.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextPortionAppend" ],
    [ "XTextRange", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextRange.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextRange" ],
    [ "XTextRangeCompare", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextRangeCompare.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextRangeCompare" ],
    [ "XTextRangeMover", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextRangeMover.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextRangeMover" ],
    [ "XTextSection", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextSection.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextSection" ],
    [ "XTextSectionsSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextSectionsSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextSectionsSupplier" ],
    [ "XTextShapesSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextShapesSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextShapesSupplier" ],
    [ "XTextTable", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextTable.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextTable" ],
    [ "XTextTableCursor", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextTableCursor.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextTableCursor" ],
    [ "XTextTablesSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextTablesSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextTablesSupplier" ],
    [ "XTextViewCursor", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextViewCursor.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextViewCursor" ],
    [ "XTextViewCursorSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextViewCursorSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextViewCursorSupplier" ],
    [ "XTextViewTextRangeSupplier", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextViewTextRangeSupplier.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XTextViewTextRangeSupplier" ],
    [ "XWordCursor", "interfacecom_1_1sun_1_1star_1_1text_1_1XWordCursor.html", "interfacecom_1_1sun_1_1star_1_1text_1_1XWordCursor" ],
    [ "TextColumnSequence", "namespacecom_1_1sun_1_1star_1_1text.html#ab10b0063383767463fa9bd0554a352a3", null ],
    [ "HorizontalAdjust", "namespacecom_1_1sun_1_1star_1_1text.html#a8105146481666b39ebbd63a934576b6c", [
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "CENTER", "namespacecom_1_1sun_1_1star_1_1text.html#adf417fe4b45f486fe88af93ad0b59efba00f6ce13ea7d341a8ed6b99840f4bbd3", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea2d192e0d040aa72b0c0e855aaf9462e5", null ]
    ] ],
    [ "NotePrintMode", "namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251c", [
      [ "NOT", "namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca0378ebc895849163b249d0b330257dd6", null ],
      [ "ONLY", "namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca620503848b4e75d10e3e198fb77a656b", null ],
      [ "DOC_END", "namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca3828017543ed76335f58a4e21298ddbe", null ],
      [ "PAGE_END", "namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca82e429858e2344acb277006228f61455", null ]
    ] ],
    [ "PageNumberType", "namespacecom_1_1sun_1_1star_1_1text.html#aeffd73e249af906f303724f66f1f01c5", [
      [ "PREV", "namespacecom_1_1sun_1_1star_1_1text.html#aeffd73e249af906f303724f66f1f01c5ab359289a088e693e1c62099baf550b39", null ],
      [ "CURRENT", "namespacecom_1_1sun_1_1star_1_1text.html#aeffd73e249af906f303724f66f1f01c5a7770173898835c0954853cb16e8d284a", null ],
      [ "NEXT", "namespacecom_1_1sun_1_1star_1_1text.html#aeffd73e249af906f303724f66f1f01c5ab13b96bf99a409e019f70dc1602532fd", null ]
    ] ],
    [ "RubyAdjust", "namespacecom_1_1sun_1_1star_1_1text.html#adf417fe4b45f486fe88af93ad0b59efb", [
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "CENTER", "namespacecom_1_1sun_1_1star_1_1text.html#adf417fe4b45f486fe88af93ad0b59efba00f6ce13ea7d341a8ed6b99840f4bbd3", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea2d192e0d040aa72b0c0e855aaf9462e5", null ],
      [ "BLOCK", "namespacecom_1_1sun_1_1star_1_1text.html#adf417fe4b45f486fe88af93ad0b59efba02fc27068fe9a3c151ffcc08ec5bb65d", null ],
      [ "INDENT_BLOCK", "namespacecom_1_1sun_1_1star_1_1text.html#adf417fe4b45f486fe88af93ad0b59efba7b64fde681ac7e545a89c6c294ea720f", null ]
    ] ],
    [ "TextContentAnchorType", "namespacecom_1_1sun_1_1star_1_1text.html#a470b1caeda4ff15fee438c8ff9e3d834", [
      [ "AT_PARAGRAPH", "namespacecom_1_1sun_1_1star_1_1text.html#a470b1caeda4ff15fee438c8ff9e3d834a32de38d6adc479d89ed19d5b87711654", null ],
      [ "AS_CHARACTER", "namespacecom_1_1sun_1_1star_1_1text.html#a470b1caeda4ff15fee438c8ff9e3d834acb5ff4ea4718bf38762e2da8c553f924", null ],
      [ "AT_PAGE", "namespacecom_1_1sun_1_1star_1_1text.html#a470b1caeda4ff15fee438c8ff9e3d834a917590287014f3ed3874009c38eb44fb", null ],
      [ "AT_FRAME", "namespacecom_1_1sun_1_1star_1_1text.html#a470b1caeda4ff15fee438c8ff9e3d834a6acbc5fee96227b754d3cd4eb11eba60", null ],
      [ "AT_CHARACTER", "namespacecom_1_1sun_1_1star_1_1text.html#a470b1caeda4ff15fee438c8ff9e3d834ae45e3452898e33daedaa7e6e6bd27458", null ]
    ] ],
    [ "WrapTextMode", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0ae", [
      [ "NONE", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aeac157bdf0b85a40d2619cbc8bc1ae5fe2", null ],
      [ "THROUGH", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea4a976fcac4ac48e3438f89d5ac2eb0a8", null ],
      [ "THROUGHT", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea557d798551f3596230d3d7ce7ee3fb74", null ],
      [ "PARALLEL", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea90606f8ca5d91452541a74f1caef1d11", null ],
      [ "DYNAMIC", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aeaaac65e0072e6ff1f4c3209d2fdd8730a", null ],
      [ "LEFT", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea2349c85ca7362adcde4c67fbd81a4432", null ],
      [ "RIGHT", "namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea2d192e0d040aa72b0c0e855aaf9462e5", null ]
    ] ],
    [ "WritingMode", "namespacecom_1_1sun_1_1star_1_1text.html#a46d11c2d08142ef2d32761c04d1aaa26", [
      [ "LR_TB", "namespacecom_1_1sun_1_1star_1_1text.html#a46d11c2d08142ef2d32761c04d1aaa26a89dc073b7a20acdd287619d6e2fe24ca", null ],
      [ "RL_TB", "namespacecom_1_1sun_1_1star_1_1text.html#a46d11c2d08142ef2d32761c04d1aaa26a548d7315e869bbc565c85abb3cd483e8", null ],
      [ "TB_RL", "namespacecom_1_1sun_1_1star_1_1text.html#a46d11c2d08142ef2d32761c04d1aaa26afb7cad1ba598b7563718fe243c089265", null ]
    ] ]
];